==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Tux/Resources/translations/Tux_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>選擇</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>縮放</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>旋轉</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>平移</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>傾斜</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>導覽列樣式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up 或 Page Down 按鍵。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>旋轉中心</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>滑鼠中鍵或 H 鍵</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>滑鼠中鍵。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>無法辨識導覽列樣式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>設定</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>環繞模式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>緊湊</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>工具提示</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>可旋轉</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Trackball</source>
      <translation>軌跡球</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Undefined</source>
      <translation>未定義</translation>
    </message>
  </context>
</TS>

==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Tux/Resources/translations/Tux_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Select</source>
      <translation>選擇</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Zoom</source>
      <translation>縮放</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotate</source>
      <translation>旋轉</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Pan</source>
      <translation>平移</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Tilt</source>
      <translation>傾斜</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="72"/>
      <source>Navigation style</source>
      <translation>導覽列樣式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="73"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up 或 Page Down 按鍵。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Rotation focus</source>
      <translation>旋轉中心</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="75"/>
      <source>Middle mouse button or H key.</source>
      <translation>滑鼠中鍵或 H 鍵</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="77"/>
      <source>Middle mouse button.</source>
      <translation>滑鼠中鍵。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="80"/>
      <source>Navigation style not recognized.</source>
      <translation>無法辨識導覽列樣式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="331"/>
      <source>Settings</source>
      <translation>設定</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="332"/>
      <source>Orbit style</source>
      <translation>環繞模式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="333"/>
      <source>Compact</source>
      <translation>緊湊</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="334"/>
      <source>Tooltip</source>
      <translation>工具提示</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="335"/>
      <source>Turntable</source>
      <translation>可旋轉</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="336"/>
      <source>Free Turntable</source>
      <translation type="unfinished">Free Turntable</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="337"/>
      <source>Trackball</source>
      <translation>軌跡球</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="338"/>
      <source>Undefined</source>
      <translation>未定義</translation>
    </message>
  </context>
</TS>
